@@ -16,7 +16,7 @@ from captur_ml_sdk.utils import get_image_components
 class BaseMdl(BaseModel):
     name: str
     version: Optional[str] = "HEAD"
-    dataset_id: str
+    dataset_id: Optional[str]
 
     _model_exists = root_validator(check_model_exists, allow_reuse=True)
 
